---
name: 🛠️ Missing Reclass feature
about: Report a missing Reclass feature 💡
labels: enhancement
---

## Missing feature
<!--
Please describe the Reclass feature that's missing. If possible, please link
to the Reclass documentation (or the Kapitan Reclass extensions documentation)
that describes the feature.
-->

## Reclass settings
<!--
Please provide your reclass settings. If you're using Kapitan, please provide
the full `reclass-config.yml` that you're using.
-->

## Example inventory
<!--
If feasible, please provide a minimal example inventory that makes use of the
missing feature. By doing so, you're making it much easier for us to implement
and test the missing feature.
-->
